@@ -1,5 +1,5 @@
 package Dancer2;
-$Dancer2::VERSION = '0.204004';
+$Dancer2::VERSION = '0.205000';
 # ABSTRACT: Lightweight yet powerful web application framework
 
 use strict;
@@ -128,7 +128,7 @@ Dancer2 - Lightweight yet powerful web application framework
 
 =head1 VERSION
 
-version 0.204004
+version 0.205000
 
 =head1 DESCRIPTION
 
@@ -267,6 +267,7 @@ Returns the current runner. It is of type L<Dancer2::Core::Runner>.
     Dale Gallagher
     Daniel Muey
     Daniel Perrett
+    David (sbts)
     David Steinbrunner
     David Zurborg
     Davs
@@ -306,6 +307,7 @@ Returns the current runner. It is of type L<Dancer2::Core::Runner>.
     Ludovic Tolhurst-Cleaver
     Mario Zieschang
     Mark A. Stratman
+    Marketa Wachtlova
     Masaaki Saito
     Mateu X Hunter
     Matt Phillips
@@ -327,6 +329,7 @@ Returns the current runner. It is of type L<Dancer2::Core::Runner>.
     Patrick Zimmermann
     Pau Amma
     Paul Cochrane
+    Paul Williams
     Pedro Bruno
     Pedro Melo
     Philippe Bricout
