@@ -1,6 +1,6 @@
 # ABSTRACT: encapsulation of Dancer2 packages
 package Dancer2::Core::App;
-$Dancer2::Core::App::VERSION = '0.204004';
+$Dancer2::Core::App::VERSION = '0.205000';
 use Moo;
 use Carp               qw<croak carp>;
 use Scalar::Util       'blessed';
@@ -30,7 +30,7 @@ use Dancer2::Core::Factory;
 
 use Dancer2::Handler::File;
 
-our $EVAL_SHIM = sub {
+our $EVAL_SHIM; $EVAL_SHIM ||= sub {
     my $code = shift;
     $code->(@_);
 };
@@ -593,6 +593,18 @@ has routes => (
     },
 );
 
+has 'calling_class' => (
+    'is'      => 'ro',
+    'isa'     => Str,
+    'default' => sub {
+        my $class = ( caller(2) )[0] ||
+                    ( caller(1) )[0] ||
+                    ( caller(0) )[0];
+
+        return $class;
+    },
+);
+
 # add_hook will add the hook to the first "hook candidate" it finds that support
 # it. If none, then it will try to add the hook to the current application.
 around add_hook => sub {
@@ -955,7 +967,7 @@ sub send_as {
 
     # load any serializer engine config
     my $engine_options =
-        $self->_get_config_for_engine( serializer => $type, {} ) || {};
+        $self->_get_config_for_engine( serializer => $type, $self->config ) || {};
     my $serializer = $serializer_class->new( config => $engine_options );
     my $content = $serializer->serialize( $data );
     $options->{content_type} ||= $serializer->content_type;
@@ -1111,6 +1123,11 @@ sub finish {
         && $self->plugins->[0]->_add_postponed_plugin_hooks(
             $self->postponed_hooks
         );
+
+    $self->calling_class->can('prepare_app')
+      and warn "WARNING: You have a subroutine in your "
+      . "app called 'prepare_app'. In the future "
+      . "this will automatically be called by Dancer2.";
 }
 
 sub init_route_handlers {
@@ -1646,7 +1663,7 @@ Dancer2::Core::App - encapsulation of Dancer2 packages
 
 =head1 VERSION
 
-version 0.204004
+version 0.205000
 
 =head1 DESCRIPTION
 
