@@ -1,6 +1,6 @@
 package Dancer2::Core::Cookie;
 # ABSTRACT: A cookie representing class
-$Dancer2::Core::Cookie::VERSION = '0.204004';
+$Dancer2::Core::Cookie::VERSION = '0.205000';
 use Moo;
 use URI::Escape;
 use Dancer2::Core::Types;
@@ -31,14 +31,18 @@ BEGIN {
 sub xs_to_header {
     my $self = shift;
 
+    # HTTP::XSCookies can't handle multi-value cookies.
+    return $self->pp_to_header(@_) if @{[ $self->value ]} > 1;
+
     return HTTP::XSCookies::bake_cookie(
         $self->name,
-        {   value    => join('&', $self->value),
+        {   value    => $self->value,
             path     => $self->path,
             domain   => $self->domain,
             expires  => $self->expires,
             httponly => $self->http_only,
             secure   => $self->secure,
+            samesite => $self->same_site,
         }
     );
 }
@@ -50,10 +54,11 @@ sub pp_to_header {
     my $no_httponly = defined( $self->http_only ) && $self->http_only == 0;
 
     my @headers = $self->name . '=' . $value;
-    push @headers, "Path=" . $self->path       if $self->path;
-    push @headers, "Expires=" . $self->expires if $self->expires;
-    push @headers, "Domain=" . $self->domain   if $self->domain;
-    push @headers, "Secure"                    if $self->secure;
+    push @headers, "Path=" . $self->path          if $self->path;
+    push @headers, "Expires=" . $self->expires    if $self->expires;
+    push @headers, "Domain=" . $self->domain      if $self->domain;
+    push @headers, "SameSite=" . $self->same_site if $self->same_site;
+    push @headers, "Secure"                       if $self->secure;
     push @headers, 'HttpOnly' unless $no_httponly;
 
     return join '; ', @headers;
@@ -126,6 +131,12 @@ has http_only => (
     default  => sub {0},
 );
 
+has same_site => (
+    is       => 'rw',
+    isa      => Enum[qw[Strict Lax]],
+    required => 0,
+);
+
 1;
 
 __END__
@@ -140,7 +151,7 @@ Dancer2::Core::Cookie - A cookie representing class
 
 =head1 VERSION
 
-version 0.204004
+version 0.205000
 
 =head1 SYNOPSIS
 
@@ -207,6 +218,11 @@ the server (via HTTP) and not by any JavaScript code.
 If your cookie is meant to be used by some JavaScript code, set this
 attribute to 0.
 
+=head2 same_site
+
+Whether the cookie ought not to be sent along with cross-site requests,
+an enum of either "Strict" or "Lax", default is unset.
+
 =head1 METHODS
 
 =head2 my $cookie=Dancer2::Core::Cookie->new(%opts);
