@@ -1,6 +1,6 @@
 package Dancer2::Core::Request;
 # ABSTRACT: Interface for accessing incoming requests
-$Dancer2::Core::Request::VERSION = '0.204004';
+$Dancer2::Core::Request::VERSION = '0.205000';
 use strict;
 use warnings;
 use parent 'Plack::Request';
@@ -274,22 +274,8 @@ sub uri_base {
 }
 
 sub dispatch_path {
-    my $self = shift;
-
-    my $path = $self->path;
-
-    # Want $self->base->path, without needing the URI object,
-    # and trim any trailing '/'.
-    my $base = '';
-    $base .= $self->script_name if defined $self->script_name;
-    $base =~ s|/+$||;
-
-    # Remove base from front of path.
-    $path =~ s|^(\Q$base\E)?||;
-    $path =~ s|^/+|/|;
-    # PSGI spec notes that '' should be considered '/'
-    $path = '/' if $path eq '';
-    return $path;
+    warn q{request->dispatch_path is deprecated};
+    return shift->path;
 }
 
 sub uri_for {
@@ -520,7 +506,7 @@ sub _read_to_end {
 
     my $body = '';
     if ( $content_length && $content_length > 0 ) {
-        while ( my $buffer = $self->_read() ) {
+        while ( length ( my $buffer = $self->_read() ) ) {
             $body .= $buffer;
         }
         $self->{_http_body}->add($body);
@@ -680,7 +666,7 @@ Dancer2::Core::Request - Interface for accessing incoming requests
 
 =head1 VERSION
 
-version 0.204004
+version 0.205000
 
 =head1 SYNOPSIS
 
@@ -738,8 +724,7 @@ content, returns the deserialized structure as a hashref.
 
 =head2 dispatch_path
 
-The part of the C<path> after C<base>. This is the path used
-for dispatching the request to routes.
+Alias for L<path>. Deprecated.
 
 =head2 env
 
