@@ -1,6 +1,6 @@
 package Dancer2::Core::Route;
 # ABSTRACT: Dancer2's route handler
-$Dancer2::Core::Route::VERSION = '0.204004';
+$Dancer2::Core::Route::VERSION = '0.205000';
 use Moo;
 use Dancer2::Core::Types;
 use Carp 'croak';
@@ -81,7 +81,7 @@ sub match {
         return unless $self->validate_options($request);
     }
 
-    my @values = $request->dispatch_path =~ $self->regexp;
+    my @values = $request->path =~ $self->regexp;
 
     return unless @values;
 
@@ -271,7 +271,7 @@ Dancer2::Core::Route - Dancer2's route handler
 
 =head1 VERSION
 
-version 0.204004
+version 0.205000
 
 =head1 ATTRIBUTES
 
